@@ -1,9 +1,7 @@
-#!/usr/local/bin/perl -w
+#!/usr/bin/perl -w
 use strict;
 use Carp 'confess', 'croak';
 use Test;
-
-# use lib '../../';  # TESTING
 use Data::Taxi;    # TESTING
 
 
@@ -12,19 +10,20 @@ BEGIN { plan tests => 1 };
 
 my ($struct, $hold);
 
-$struct = 
-	{
-	
+$struct = {
 	name => 'Miko',
 	
 	schools => [
 		'Cardinal Forest',
 		'Robinson',
 		'VA Tech',
-		],
-	};
+	],
+};
 
 $hold = Data::Taxi::freeze($struct);
+
+# die "early exit\n";
+
 $struct = Data::Taxi::thaw($hold);
 
 if ($struct->{'schools'}->[1] eq 'Robinson')
